Index: src/gpu/SkGpuDevice.h |
diff --git a/src/gpu/SkGpuDevice.h b/src/gpu/SkGpuDevice.h |
index 8d557bc6b6cd95b5a329f187c8c78c8b22f855ec..5f876a3135f5affee30309c87c5721751bb0d3b2 100644 |
--- a/src/gpu/SkGpuDevice.h |
+++ b/src/gpu/SkGpuDevice.h |
@@ -50,7 +50,7 @@ public: |
/** |
* New device that will create an offscreen renderTarget based on the ImageInfo and |
* sampleCount. The Budgeted param controls whether the device's backing store counts against |
* the resource cache budget. On failure, returns NULL. |
*/ |
static SkGpuDevice* Create(GrContext*, SkSurface::Budgeted, const SkImageInfo&, |
int sampleCount, const SkSurfaceProps*, InitContents); |
@@ -60,7 +60,7 @@ public: |
SkGpuDevice* cloneDevice(const SkSurfaceProps& props) { |
SkBaseDevice* dev = this->onCreateDevice(CreateInfo(this->imageInfo(), kPossible_TileUsage, |
props.pixelGeometry()), |
- NULL); |
+ nullptr); |
return static_cast<SkGpuDevice*>(dev); |
} |
@@ -184,7 +184,7 @@ private: |
void drawBitmapCommon(const SkDraw&, |
const SkBitmap& bitmap, |
const SkRect* srcRectPtr, |
- const SkSize* dstSizePtr, // ignored iff srcRectPtr == NULL |
+ const SkSize* dstSizePtr, // ignored iff srcRectPtr == nullptr |
const SkPaint&, |
SkCanvas::SrcRectConstraint); |
@@ -50,7 +50,7 @@ public: |
* New device that will create an offscreen renderTarget based on the ImageInfo and |
* sampleCount. The Budgeted param controls whether the device's backing store counts against |
- * the resource cache budget. On failure, returns NULL. |
+ * the resource cache budget. On failure, returns nullptr. |
*/ |
static SkGpuDevice* Create(GrContext*, SkSurface::Budgeted, const SkImageInfo&, |